Signed-off-by: Samuel Pitoiset <samuel.pitoi...@gmail.com>
---
 src/mesa/main/texstorage.c | 24 ++++++++++++------------
 src/mesa/main/texstorage.h |  7 -------
 2 files changed, 12 insertions(+), 19 deletions(-)

diff --git a/src/mesa/main/texstorage.h b/src/mesa/main/texstorage.h
index e80a9ff5b9..526c61e851 100644
--- a/src/mesa/main/texstorage.h
+++ b/src/mesa/main/texstorage.h
@@ -31,13 +31,6 @@
  */
 /*@{*/
 
-extern void
-_mesa_texture_storage(struct gl_context *ctx, GLuint dims,
-                      struct gl_texture_object *texObj,
-                      GLenum target, GLsizei levels,
-                      GLenum internalformat, GLsizei width,
-                      GLsizei height, GLsizei depth, bool dsa);
-
 /**
  * Texture width, height and depth check shared with the
  * multisample variants of TexStorage functions.
diff --git a/src/mesa/main/texstorage.c b/src/mesa/main/texstorage.c
index 958c7b7a67..7519ca2807 100644
--- a/src/mesa/main/texstorage.c
+++ b/src/mesa/main/texstorage.c
@@ -386,12 +386,12 @@ tex_storage_error_check(struct gl_context *ctx,
  * Helper that does the storage allocation for _mesa_TexStorage1/2/3D()
  * and _mesa_TextureStorage1/2/3D().
  */
-void
-_mesa_texture_storage(struct gl_context *ctx, GLuint dims,
-                      struct gl_texture_object *texObj,
-                      GLenum target, GLsizei levels,
-                      GLenum internalformat, GLsizei width,
-                      GLsizei height, GLsizei depth, bool dsa)
+static void
+texture_storage(struct gl_context *ctx, GLuint dims,
+                struct gl_texture_object *texObj,
+                GLenum target, GLsizei levels,
+                GLenum internalformat, GLsizei width,
+                GLsizei height, GLsizei depth, bool dsa)
 {
    GLboolean sizeOK, dimensionsOK;
    mesa_format texFormat;
@@ -480,7 +480,7 @@ texstorage(GLuint dims, GLenum target, GLsizei levels, 
GLenum internalformat,
    struct gl_texture_object *texObj;
    GET_CURRENT_CONTEXT(ctx);
 
    /* Check target.  This is done here so that _mesa_texture_storage
     * can receive unsized formats.
     */
    if (!legal_texobj_target(ctx, dims, target)) {
@@ -509,8 +509,8 @@ texstorage(GLuint dims, GLenum target, GLsizei levels, 
GLenum internalformat,
    if (!texObj)
       return;
 
-   _mesa_texture_storage(ctx, dims, texObj, target, levels,
-                         internalformat, width, height, depth, false);
+   texture_storage(ctx, dims, texObj, target, levels,
+                   internalformat, width, height, depth, false);
 }
 
 
@@ -543,7 +543,7 @@ texturestorage(GLuint dims, GLuint texture, GLsizei levels,
    if (!texObj)
       return;
 
    /* Check target.  This is done here so that _mesa_texture_storage
     * can receive unsized formats.
     */
    if (!legal_texobj_target(ctx, dims, texObj->Target)) {
@@ -553,8 +553,8 @@ texturestorage(GLuint dims, GLuint texture, GLsizei levels,
       return;
    }
 
-   _mesa_texture_storage(ctx, dims, texObj, texObj->Target,
-                         levels, internalformat, width, height, depth, true);
+   texture_storage(ctx, dims, texObj, texObj->Target,
+                   levels, internalformat, width, height, depth, true);
 }
 
 
@@ -480,7 +480,7 @@ texstorage(GLuint dims, GLenum target, GLsizei levels, 
    GET_CURRENT_CONTEXT(ctx);
 
-   /* Check target.  This is done here so that _mesa_texture_storage
+   /* Check target.  This is done here so that texture_storage
     * can receive unsized formats.
     */
@@ -543,7 +543,7 @@ texturestorage(GLuint dims, GLuint texture, GLsizei levels,
       return;
 
-   /* Check target.  This is done here so that _mesa_texture_storage
+   /* Check target.  This is done here so that texture_storage
     * can receive unsized formats.
     */
-- 
2.13.3

_______________________________________________
mesa-dev mailing list
mesa-dev@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/mesa-dev

Reply via email to